@@ -52,7 +52,7 @@ parser.add_argument("--orientations", help="Orientations to consider for trainin
 # optimization parameters
 parser.add_argument("--loss", help="Specifies the loss function (and optionally, additional parameters separated by "
                                    "hashtags and colons that specify the name) used for optimization",
-                    type=str, default="dice")
+                    type=str, default="ce")
 parser.add_argument("--lr", help="Learning rate of the optimization", type=float, default=1e-3)
 parser.add_argument("--step_size", help="Number of epochs after which the learning rate should decay",
                     type=int, default=10)
